@@ -6,9 +6,9 @@ testthat::test_that(
     # 2) to align the indices,
     # we use the convincience functions
     # by splitting the FGI by the BTC index.
-    FGIndex <- splitWindow(
+    FGIndex <- split_window(
       xts = FGIndex,
-      by  = zoo::index(BTCUSDT),
+      by  = zoo::index(BTC),
 
       # Remove upper bounds of the
       # index to avoid overlap between
@@ -23,7 +23,7 @@ testthat::test_that(
     # 3) as splitWindow returns a list
     # it needs to passed into calibrateWindow
     # to ensure comparability
-    FGIndex <- calibrateWindow(
+    FGIndex <- calibrate_window(
       list = FGIndex,
 
       # As each element in the list can include
@@ -39,7 +39,7 @@ testthat::test_that(
     # 3) check if candles aligns
     # accordingly
     testthat::expect_equal(
-      zoo::index(BTCUSDT),
+      zoo::index(BTC),
       zoo::index(FGIndex)
     )
 
