@@ -1,12 +1,17 @@
 testthat::test_that(
-  desc = "getFNG returns 100 values",
+  desc = "getFNG returns 200 values",
   code = {
 
+    # 0) skip if online;
+    testthat::skip_if_offline()
+
     # 1) skip on github
     testthat::skip_on_ci()
 
     # 2) load FGI
-    FGI <- getFGIndex()
+    FGI <- get_fgindex(
+      to = Sys.Date() - 1
+      )
 
     # 3) test that its an
     # xts object
@@ -21,7 +26,7 @@ testthat::test_that(
     # 100 rows
     testthat::expect_equal(
       object   = nrow(FGI),
-      expected = 100
+      expected = 200
     )
 
   }
